atomate.vasp.tests package — atomate 0.9.2 documentation

# atomate.vasp.tests package

## Submodules

## atomate.vasp.tests.test_drones module

class `atomate.vasp.tests.test_drones.` `VaspToDbTaskDroneTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_assimilate`()
  `test_bandstructure`()
  `test_detect_output_file_paths`()
  `test_parse_chrgcar`()
  `test_parse_locpot`()
  `test_runs_assimilate`()

## atomate.vasp.tests.test_setup module

class `atomate.vasp.tests.test_setup.` `TestSetup`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `tearDown`()

    Hook method for deconstructing the test fixture after testing it.

  `test_setup`()

## atomate.vasp.tests.test_vasp_powerups module

class `atomate.vasp.tests.test_vasp_powerups.` `TestVaspPowerups`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_add_clean_up`()
  `test_add_priority`()
  `test_add_small_gap_multiply`()
  `test_add_tags`()
  `test_add_trackers`()
  `test_add_wf_metadata`()
  `test_custodian_powerups`()
  `test_modify_incar`()
  `test_modify_potcar`()
  `test_use_scratch_dir`()

## Module contents